- name hiding - html
Kev
Index: Ant.java
===================================================================
RCS file: /home/cvspublic/ant/src/main/org/apache/tools/ant/taskdefs/Ant.java,v
retrieving revision 1.116
diff -u -r1.116 Ant.java
--- Ant.java 14 Jan 2005 17:23:37 -0000 1.116
+++ Ant.java 1 Feb 2005 12:11:42 -0000
@@ -79,7 +79,7 @@
private String antFile = null;
/** the output */
- private String output = null;
+ private String output = null;
/** should we inherit properties from the parent ? */
private boolean inheritAll = true;
@@ -206,20 +206,18 @@
/**
* @see Task#handleOutput(String)
- *
* @since Ant 1.5
*/
- public void handleOutput(String output) {
+ public void handleOutput(String outputToHandle) {
if (newProject != null) {
- newProject.demuxOutput(output, false);
+ newProject.demuxOutput(outputToHandle, false);
} else {
- super.handleOutput(output);
+ super.handleOutput(outputToHandle);
}
}
/**
* @see Task#handleInput(byte[], int, int)
- *
* @since Ant 1.6
*/
public int handleInput(byte[] buffer, int offset, int length)
@@ -233,40 +231,37 @@
/**
* @see Task#handleFlush(String)
- *
* @since Ant 1.5.2
*/
- public void handleFlush(String output) {
+ public void handleFlush(String toFlush) {
if (newProject != null) {
- newProject.demuxFlush(output, false);
+ newProject.demuxFlush(toFlush, false);
} else {
- super.handleFlush(output);
+ super.handleFlush(toFlush);
}
}
/**
* @see Task#handleErrorOutput(String)
- *
* @since Ant 1.5
*/
- public void handleErrorOutput(String output) {
+ public void handleErrorOutput(String errorOutputToHandle) {
if (newProject != null) {
- newProject.demuxOutput(output, true);
+ newProject.demuxOutput(errorOutputToHandle, true);
} else {
- super.handleErrorOutput(output);
+ super.handleErrorOutput(errorOutputToHandle);
}
}
/**
* @see Task#handleErrorFlush(String)
- *
* @since Ant 1.5.2
*/
- public void handleErrorFlush(String output) {
+ public void handleErrorFlush(String errorOutputToFlush) {
if (newProject != null) {
- newProject.demuxFlush(output, true);
+ newProject.demuxFlush(errorOutputToFlush, true);
} else {
- super.handleErrorFlush(output);
+ super.handleErrorFlush(errorOutputToFlush);
}
}
@@ -576,10 +571,10 @@
* Defaults to the current project's basedir, unless inheritall
* has been set to false, in which case it doesn't have a default
* value. This will override the basedir setting of the called project.
- * @param d new directory as <code>File</code>.
+ * @param dir new directory as <code>File</code>.
*/
- public void setDir(File d) {
- this.dir = d;
+ public void setDir(File dir) {
+ this.dir = dir;
}
/**
@@ -587,23 +582,23 @@
* to be a filename relative to the dir attribute given.
* @param s the <code>String</code> build file name.
*/
- public void setAntfile(String s) {
+ public void setAntfile(String antFile) {
// @note: it is a string and not a file to handle relative/absolute
// otherwise a relative file will be resolved based on the current
// basedir.
- this.antFile = s;
+ this.antFile = antFile;
}
/**
* The target of the new Ant project to execute.
* Defaults to the new project's default target.
* @param s the name of the target to invoke.
*/
- public void setTarget(String s) {
- if (s.equals("")) {
+ public void setTarget(String targetToAdd) {
+ if (targetToAdd.equals("")) {
throw new BuildException("target attribute must not be empty");
}
- targets.add(s);
+ targets.add(targetToAdd);
targetAttributeSet = true;
}
@@ -611,10 +606,10 @@
* Set the filename to write the output to. This is relative to the value
* of the dir attribute if it has been set or to the base directory of the
* current project otherwise.
* @param s the name of the file to which the output should go.
*/
- public void setOutput(String s) {
- this.output = s;
+ public void setOutput(String outputFile) {
+ this.output = outputFile;
}
/**
@@ -636,10 +631,10 @@
/**
* Add a Reference element identifying a data type to carry
* over to the new project.
- * @param r <code>Reference</code> to add.
+ * @param ref <code>Reference</code> to add.
*/
- public void addReference(Reference r) {
- references.addElement(r);
+ public void addReference(Reference ref) {
+ references.addElement(ref);
}
/**
@@ -685,7 +680,7 @@
/** Creates a reference to be configured by Ant. */
public Reference() {
- super();
+ super();
}
private String targetid = null;
@@ -727,7 +722,7 @@
/**
* Set the name of this TargetElement.
- * @param name the <CODE>String</CODE> target name.
+ * @param name the <code>String</code> target name.
*/
public void setName(String name) {
this.name = name;
@@ -735,7 +730,7 @@
/**
* Get the name of this TargetElement.
- * @return <CODE>String</CODE>.
+ * @return <code>String</code>.
*/
public String getName() {
return name;--------------------------------------------------------------------- To unsubscribe, e-mail: [EMAIL PROTECTED] For additional commands, e-mail: [EMAIL PROTECTED]
@@ -587,23 +582,23 @@
* The target of the new Ant project to execute.
* Defaults to the new project's default target.
- * @param s the name of the target to invoke.
+ * @param targetToAdd the name of the target to invoke.
*/
@@ -611,10 +606,10 @@
* of the dir attribute if it has been set or to the base directory of the
* current project otherwise.
- * @param s the name of the file to which the output should go.
+ * @param outputFile the name of the file to which the output should go.
*/
